==> phpcpd_2.0.1.orig.tar.gz: phpcpd-2.0.1/src/Detector/Strategy/Abstract.php <==
<?php
/**
 * phpcpd
 *
 * Copyright (c) 2009-2014, Sebastian Bergmann <sebastian@phpunit.de>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   * Neither the name of Sebastian Bergmann nor the names of his
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @package   phpcpd
 * @author    Sebastian Bergmann <sebastian@phpunit.de>
 * @copyright 2009-2014 Sebastian Bergmann <sebastian@phpunit.de>
 * @license   http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
 * @since     File available since Release 1.4.0
 */

namespace SebastianBergmann\PHPCPD\Detector\Strategy;

use SebastianBergmann\PHPCPD\CodeCloneMap;

/**
 * Abstract base class for strategies to detect code clones.
 *
 * @author    Sebastian Bergmann <sebastian@phpunit.de>
 * @copyright 2009-2014 Sebastian Bergmann <sebastian@phpunit.de>
 * @license   http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
 * @link      http://github.com/sebastianbergmann/phpcpd/tree
 * @since     Class available since Release 1.4.0
 */
abstract class AbstractStrategy
{
    /**
     * @var integer[] List of tokens to ignore
     */
    protected $tokensIgnoreList = array(
      T_INLINE_HTML => true,
      T_COMMENT => true,
      T_DOC_COMMENT => true,
      T_OPEN_TAG => true,
      T_OPEN_TAG_WITH_ECHO => true,
      T_CLOSE_TAG => true,
      T_WHITESPACE => true,
      T_USE => true,
      T_NS_SEPARATOR => true
    );

    /**
     * @var string[]
     */
    protected $hashes = array();

    /**
     * Copy & Paste Detection (CPD).
     *
     * @param string       $file
     * @param integer      $minLines
     * @param integer      $minTokens
     * @param CodeCloneMap $result
     * @param boolean      $fuzzy
     */
    abstract public function processFile($file, $minLines, $minTokens, CodeCloneMap $result, $fuzzy = false);
}

==> phpcpd_2.0.2.orig.tar.gz: phpcpd-2.0.2/src/Detector/Strategy/Abstract.php <==
<?php
/*
 * This file is part of PHP Copy/Paste Detector (PHPCPD).
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace SebastianBergmann\PHPCPD\Detector\Strategy;

use SebastianBergmann\PHPCPD\CodeCloneMap;

/**
 * Abstract base class for strategies to detect code clones.
 *
 * @author    Sebastian Bergmann <sebastian@phpunit.de>
 * @copyright Sebastian Bergmann <sebastian@phpunit.de>
 * @license   http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
 * @link      http://github.com/sebastianbergmann/phpcpd/tree
 * @since     Class available since Release 1.4.0
 */
abstract class AbstractStrategy
{
    /**
     * @var integer[] List of tokens to ignore
     */
    protected $tokensIgnoreList = array(
      T_INLINE_HTML => true,
      T_COMMENT => true,
      T_DOC_COMMENT => true,
      T_OPEN_TAG => true,
      T_OPEN_TAG_WITH_ECHO => true,
      T_CLOSE_TAG => true,
      T_WHITESPACE => true,
      T_USE => true,
      T_NS_SEPARATOR => true
    );

    /**
     * @var string[]
     */
    protected $hashes = array();

    /**
     * Copy & Paste Detection (CPD).
     *
     * @param string       $file
     * @param integer      $minLines
     * @param integer      $minTokens
     * @param CodeCloneMap $result
     * @param boolean      $fuzzy
     */
    abstract public function processFile($file, $minLines, $minTokens, CodeCloneMap $result, $fuzzy = false);
}
